@@ -25,6 +25,15 @@
 #'
 #' * `current_package` `<string>` (read only): name of package being documented.
 #'
+#' * `rd_family_title` `<list>`: overrides for `@family` titles. See the
+#'    _rd_ vignette for details: `vignette("rd", package = "roxygen2")`
+#'
+#' * `knitr_chunk_options`: default chunk options used for knitr.
+#'
+#' * `restrict_image_formats`: if `TRUE` then PDF images are only included in the
+#'   PDF manual, and SVG images are only included in the HTML manual.
+#'   (This only applies to images supplied via markdown.)
+#'
 #' @section How to set:
 #' Either set in `DESCRIPTION`:
 #'
@@ -56,7 +65,10 @@ load_options <- function(base_path = ".") {
     old_usage = FALSE,
     markdown = FALSE,
     r6 = TRUE,
-    current_package = NA_character_
+    current_package = NA_character_,
+    rd_family_title = list(),
+    knitr_chunk_options = NULL,
+    restrict_image_formats = TRUE
   )
 
   unknown_opts <- setdiff(names(opts), names(defaults))
@@ -109,7 +121,7 @@ load_options_meta <- function(base_path = ".", path = "man/roxygen/meta.R") {
   value
 }
 
-# Global binding mangaemnet -----------------------------------------------
+# Global binding management -----------------------------------------------
 
 roxy_meta <- new_environment()
 
@@ -132,3 +144,9 @@ roxy_meta_load <- function(base_path = getwd()) {
   env_bind(roxy_meta, !!!load_options(base_path))
 }
 
+local_roxy_meta_set <- function(key, value, envir = caller_env()) {
+  old_value <- roxy_meta_get(key)
+  withr::defer(roxy_meta_set(key, old_value), envir = envir)
+
+  roxy_meta_set(key, value)
+}
